import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DbProxyEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#db_proxy_endpoint_name DbProxyEndpoint#db_proxy_endpoint_name}.
     *
     * @stability stable
     */
    readonly dbProxyEndpointName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#db_proxy_name DbProxyEndpoint#db_proxy_name}.
     *
     * @stability stable
     */
    readonly dbProxyName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#tags DbProxyEndpoint#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#tags_all DbProxyEndpoint#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#target_role DbProxyEndpoint#target_role}.
     *
     * @stability stable
     */
    readonly targetRole?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#vpc_security_group_ids DbProxyEndpoint#vpc_security_group_ids}.
     *
     * @stability stable
     */
    readonly vpcSecurityGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#vpc_subnet_ids DbProxyEndpoint#vpc_subnet_ids}.
     *
     * @stability stable
     */
    readonly vpcSubnetIds: string[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#timeouts DbProxyEndpoint#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DbProxyEndpointTimeouts;
}
/**
 * @stability stable
 */
export interface DbProxyEndpointTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#create DbProxyEndpoint#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#delete DbProxyEndpoint#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#update DbProxyEndpoint#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html aws_db_proxy_endpoint}.
 *
 * @stability stable
 */
export declare class DbProxyEndpoint extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html aws_db_proxy_endpoint} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DbProxyEndpointConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _dbProxyEndpointName;
    /**
     * @stability stable
     */
    get dbProxyEndpointName(): string;
    /**
     * @stability stable
     */
    set dbProxyEndpointName(value: string);
    /**
     * @stability stable
     */
    get dbProxyEndpointNameInput(): string;
    private _dbProxyName;
    /**
     * @stability stable
     */
    get dbProxyName(): string;
    /**
     * @stability stable
     */
    set dbProxyName(value: string);
    /**
     * @stability stable
     */
    get dbProxyNameInput(): string;
    /**
     * @stability stable
     */
    get endpoint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get isDefault(): boolean;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _targetRole?;
    /**
     * @stability stable
     */
    get targetRole(): string;
    /**
     * @stability stable
     */
    set targetRole(value: string);
    /**
     * @stability stable
     */
    resetTargetRole(): void;
    /**
     * @stability stable
     */
    get targetRoleInput(): string | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    private _vpcSecurityGroupIds?;
    /**
     * @stability stable
     */
    get vpcSecurityGroupIds(): string[];
    /**
     * @stability stable
     */
    set vpcSecurityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetVpcSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get vpcSecurityGroupIdsInput(): string[] | undefined;
    private _vpcSubnetIds;
    /**
     * @stability stable
     */
    get vpcSubnetIds(): string[];
    /**
     * @stability stable
     */
    set vpcSubnetIds(value: string[]);
    /**
     * @stability stable
     */
    get vpcSubnetIdsInput(): string[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DbProxyEndpointTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DbProxyEndpointTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DbProxyEndpointTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
