import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KmsGrantConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#grant_creation_tokens KmsGrant#grant_creation_tokens}.
     *
     * @stability stable
     */
    readonly grantCreationTokens?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#grantee_principal KmsGrant#grantee_principal}.
     *
     * @stability stable
     */
    readonly granteePrincipal: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#key_id KmsGrant#key_id}.
     *
     * @stability stable
     */
    readonly keyId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#name KmsGrant#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#operations KmsGrant#operations}.
     *
     * @stability stable
     */
    readonly operations: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#retire_on_delete KmsGrant#retire_on_delete}.
     *
     * @stability stable
     */
    readonly retireOnDelete?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#retiring_principal KmsGrant#retiring_principal}.
     *
     * @stability stable
     */
    readonly retiringPrincipal?: string;
    /**
     * constraints block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#constraints KmsGrant#constraints}
     *
     * @stability stable
     */
    readonly constraints?: KmsGrantConstraints[];
}
/**
 * @stability stable
 */
export interface KmsGrantConstraints {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#encryption_context_equals KmsGrant#encryption_context_equals}.
     *
     * @stability stable
     */
    readonly encryptionContextEquals?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#encryption_context_subset KmsGrant#encryption_context_subset}.
     *
     * @stability stable
     */
    readonly encryptionContextSubset?: {
        [key: string]: string;
    };
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html aws_kms_grant}.
 *
 * @stability stable
 */
export declare class KmsGrant extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html aws_kms_grant} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KmsGrantConfig);
    private _grantCreationTokens?;
    /**
     * @stability stable
     */
    get grantCreationTokens(): string[];
    /**
     * @stability stable
     */
    set grantCreationTokens(value: string[]);
    /**
     * @stability stable
     */
    resetGrantCreationTokens(): void;
    /**
     * @stability stable
     */
    get grantCreationTokensInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get grantId(): string;
    /**
     * @stability stable
     */
    get grantToken(): string;
    private _granteePrincipal;
    /**
     * @stability stable
     */
    get granteePrincipal(): string;
    /**
     * @stability stable
     */
    set granteePrincipal(value: string);
    /**
     * @stability stable
     */
    get granteePrincipalInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _keyId;
    /**
     * @stability stable
     */
    get keyId(): string;
    /**
     * @stability stable
     */
    set keyId(value: string);
    /**
     * @stability stable
     */
    get keyIdInput(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operations;
    /**
     * @stability stable
     */
    get operations(): string[];
    /**
     * @stability stable
     */
    set operations(value: string[]);
    /**
     * @stability stable
     */
    get operationsInput(): string[];
    private _retireOnDelete?;
    /**
     * @stability stable
     */
    get retireOnDelete(): boolean;
    /**
     * @stability stable
     */
    set retireOnDelete(value: boolean);
    /**
     * @stability stable
     */
    resetRetireOnDelete(): void;
    /**
     * @stability stable
     */
    get retireOnDeleteInput(): boolean | undefined;
    private _retiringPrincipal?;
    /**
     * @stability stable
     */
    get retiringPrincipal(): string;
    /**
     * @stability stable
     */
    set retiringPrincipal(value: string);
    /**
     * @stability stable
     */
    resetRetiringPrincipal(): void;
    /**
     * @stability stable
     */
    get retiringPrincipalInput(): string | undefined;
    private _constraints?;
    /**
     * @stability stable
     */
    get constraints(): KmsGrantConstraints[];
    /**
     * @stability stable
     */
    set constraints(value: KmsGrantConstraints[]);
    /**
     * @stability stable
     */
    resetConstraints(): void;
    /**
     * @stability stable
     */
    get constraintsInput(): KmsGrantConstraints[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
